@@ -76,7 +76,7 @@ def get_mims_summary(min_before, prompt_time, closest_times, df_logs_combined):
 def match_feature(prompt_local_datetime_series, df_logs_combined):
     print("     --- start matching")
     # Aggregating minutes before prompt time
-    min_before_list = list(range(1, 11))
+    min_before_list = [60*x for x in list(range(1, 11))]
 
     mims_summary_list = []
     start_time_list = []
@@ -117,11 +117,10 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
     df = pd.DataFrame()
     for min_before in min_before_list:
-        col = min_before - 1
-        df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + str(min_before) + "min")], axis=1)
-        df = pd.concat([df, readings_df[col].rename("num_readings_" + str(min_before) + "min")], axis=1)
-        df = pd.concat([df, start_time_df[col].rename("start_time_" + str(min_before) + "min")], axis=1)
-
+        col = int(min_before//60 - 1)
+        df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + str(min_before//60) + "min")], axis=1)
+        df = pd.concat([df, readings_df[col].rename("num_readings_" + str(min_before//60) + "min")], axis=1)
+        df = pd.concat([df, start_time_df[col].rename("start_time_" + str(min_before//60) + "min")], axis=1)
 
     return df
 
@@ -132,11 +131,10 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
     # Read, parse and combine related intermediate file
     df_logs_combined = combine_intermediate_file(intermediate_participant_path, date_in_study)
 
-    if df_logs_combined.shape[0] > 0:
-        # Match the combined parsed intermediate file with prompt feature data frame
-        df = match_feature(prompt_local_datetime_series, df_logs_combined)
-    else:
-        df = pd.DataFrame()
+
+    # Match the combined parsed intermediate file with prompt feature data frame
+    df = match_feature(prompt_local_datetime_series, df_logs_combined)
+
 
     return df
 
